@@ -41,7 +41,7 @@ from mlflow.models import Model
 from mlflow.tracking.artifact_utils import _download_artifact_from_uri
 from tritonclient.utils import InferenceServerException, np_to_triton_dtype
 
-from .config import Config, check_env
+from .config import _TritonConfig, check_env
 from .model_config import InputOutput, ModelConfig
 
 logger = logging.getLogger(__name__)
@@ -51,10 +51,34 @@ _MLFLOW_META_FILENAME = "mlflow-meta.json"
 
 class TritonPlugin(BaseDeploymentClient):
     def __init__(self, uri: Optional[str] = None):
-        """Initialize the deployment plugin, sets the triton model repo."""
+        """
+        Initialize the deployment plugin.
+
+        Args:
+            uri: Target URI for the deployment (optional)
+
+        Environment Variables:
+            MODEL_NAME: Default model name for predictions (optional).
+                       If set, predict() can be called without model_name parameter.
+
+        Example:
+            # With MODEL_NAME environment variable
+            export MODEL_NAME="yolo-v8"
+            triton = TritonPlugin()
+            result = triton.predict(df=inputs)  # Uses MODEL_NAME from env
+
+            # Without MODEL_NAME (must specify each time)
+            triton = TritonPlugin()
+            result = triton.predict(model_name="yolo-v8", df=inputs)
+
+        """
         check_env()
         super(TritonPlugin, self).__init__(target_uri=uri)
-        self.server_config = Config()
+        self._config = _TritonConfig()
+        self.model_name = self._config.get("model_name")  # Read from environment
+        self._triton_url = self._config["triton_url"]
+        self._triton_model_repo = self._config["triton_model_repo"]
+
         triton_url, self.triton_model_repo = self._get_triton_server_config()
         # need to add other flavors
         self.supported_flavors = ["triton", "onnx"]
@@ -231,13 +255,13 @@ class TritonPlugin(BaseDeploymentClient):
                 mlflow_meta_path = (
                     Path(self.triton_model_repo) / d["name"] / _MLFLOW_META_FILENAME
                 )
-                if "s3" in self.server_config:
+                if self._config.get("s3") is not None:
                     meta_dict = ast.literal_eval(
-                        self.server_config["s3"]
+                        self._config["s3"]
                         .get_object(
-                            Bucket=self.server_config["s3_bucket"],
+                            Bucket=self._config["s3_bucket"],
                             Key=str(
-                                Path(self.server_config["s3_prefix"])
+                                Path(self._config["s3_prefix"])
                                 / d["name"]
                                 / _MLFLOW_META_FILENAME
                             ),
@@ -290,7 +314,13 @@ class TritonPlugin(BaseDeploymentClient):
             print(f"Failed to unload model {model_name}")
             raise MlflowException(str(ex))
 
-    def predict(self, model_name: str, df):  # type: ignore[override]
+    def predict(self, df, model_name: Optional[str] = None):  # type: ignore[override]
+        model_name = model_name if model_name else self.model_name
+        if not model_name:
+            raise ValueError(
+                "model_name must be provided either via MODEL_NAME environment variable or predict() parameter"
+            )
+
         single_input_np = None
         if isinstance(df, np.ndarray):
             single_input_np = df
@@ -318,10 +348,10 @@ class TritonPlugin(BaseDeploymentClient):
             raise MlflowException(str(ex))
 
     def _get_triton_server_config(self):
-        triton_url = self.server_config["triton_url"]
+        triton_url = self._triton_url
         logger.info(f"Triton url = {triton_url}")
 
-        triton_model_repo = self.server_config["triton_model_repo"]
+        triton_model_repo = self._triton_model_repo
         logger.info(f"Triton model repo = {triton_model_repo}")
 
         return triton_url, triton_model_repo
@@ -335,13 +365,11 @@ class TritonPlugin(BaseDeploymentClient):
             "flavor": flavor,
         }
 
-        if "s3" in self.server_config:
-            self.server_config["s3"].put_object(
+        if self._config.get("s3") is not None:
+            self._config["s3"].put_object(
                 Body=json.dumps(meta_dict, indent=4).encode("utf-8"),
-                Bucket=self.server_config["s3_bucket"],
-                Key=str(
-                    Path(self.server_config["s3_prefix"]) / name / _MLFLOW_META_FILENAME
-                ),
+                Bucket=self._config["s3_bucket"],
+                Key=str(Path(self._config["s3_prefix"]) / name / _MLFLOW_META_FILENAME),
             )
         else:
             with (triton_deployment_dir / _MLFLOW_META_FILENAME).open("w") as outfile:
@@ -352,15 +380,13 @@ class TritonPlugin(BaseDeploymentClient):
     def _get_mlflow_meta_dict(self, name):
         mlflow_meta_path = Path(self.triton_model_repo) / name / _MLFLOW_META_FILENAME
 
-        if "s3" in self.server_config:
+        if self._config.get("s3") is not None:
             mlflow_meta_dict = ast.literal_eval(
-                self.server_config["s3"]
+                self._config["s3"]
                 .get_object(
-                    Bucket=self.server_config["s3_bucket"],
+                    Bucket=self._config["s3_bucket"],
                     Key=str(
-                        Path(self.server_config["s3_prefix"])
-                        / name
-                        / _MLFLOW_META_FILENAME
+                        Path(self._config["s3_prefix"]) / name / _MLFLOW_META_FILENAME
                     ),
                 )["Body"]
                 .read()
@@ -455,7 +481,7 @@ class TritonPlugin(BaseDeploymentClient):
         copy_paths = self._get_copy_paths(artifact_path, name, flavor)
         print(copy_paths)
         for key in copy_paths:
-            if "s3" in self.server_config:
+            if self._config.get("s3") is not None:
                 # copy model dir to s3 recursively
                 for root, dirs, files in self._walk(copy_paths[key]["from"]):
                     for filename in files:
@@ -463,9 +489,9 @@ class TritonPlugin(BaseDeploymentClient):
 
                         if flavor == "onnx":
                             s3_path = str(
-                                Path(self.server_config["s3_prefix"])
+                                Path(self._config["s3_prefix"])
                                 / Path(copy_paths[key]["to"]).relative_to(
-                                    self.server_config["triton_model_repo"]
+                                    self._triton_model_repo
                                 )
                                 / filename
                             )
@@ -475,12 +501,12 @@ class TritonPlugin(BaseDeploymentClient):
                                 copy_paths[key]["from"]
                             )
                             s3_path = str(
-                                Path(self.server_config["s3_prefix"]) / name / rel_path
+                                Path(self._config["s3_prefix"]) / name / rel_path
                             )
 
-                        self.server_config["s3"].upload_file(
+                        self._config["s3"].upload_file(
                             local_path,
-                            self.server_config["s3_bucket"],
+                            self._config["s3_bucket"],
                             # "model.onnx",
                             s3_path,
                         )
@@ -496,7 +522,7 @@ class TritonPlugin(BaseDeploymentClient):
                         to_path.mkdir(parents=True, exist_ok=True)
                     shutil.copy(from_path, to_path)
 
-        if "s3" not in self.server_config:
+        if self._config.get("s3") is None:
             triton_deployment_dir = Path(self.triton_model_repo) / name
             version_folder = triton_deployment_dir / "1"
             version_folder.mkdir(parents=True, exist_ok=True)
@@ -504,9 +530,9 @@ class TritonPlugin(BaseDeploymentClient):
         return copy_paths
 
     def _delete_mlflow_meta(self, filepath):
-        if "s3" in self.server_config:
-            self.server_config["s3"].delete_object(
-                Bucket=self.server_config["s3_bucket"],
+        if self._config.get("s3") is not None:
+            self._config["s3"].delete_object(
+                Bucket=self._config["s3_bucket"],
                 Key=filepath,
             )
         elif Path(filepath).is_file():
@@ -515,17 +541,17 @@ class TritonPlugin(BaseDeploymentClient):
     def _delete_deployment_files(self, name):
         triton_deployment_dir = Path(self.triton_model_repo) / name
 
-        if "s3" in self.server_config:
-            objs = self.server_config["s3"].list_objects(
-                Bucket=self.server_config["s3_bucket"],
-                Prefix=str(Path(self.server_config["s3_prefix"]) / name),
+        if self._config.get("s3") is not None:
+            objs = self._config["s3"].list_objects(
+                Bucket=self._config["s3_bucket"],
+                Prefix=str(Path(self._config["s3_prefix"]) / name),
             )
 
             for key in objs["Contents"]:
                 key = key["Key"]
                 try:
-                    self.server_config["s3"].delete_object(
-                        Bucket=self.server_config["s3_bucket"],
+                    self._config["s3"].delete_object(
+                        Bucket=self._config["s3_bucket"],
                         Key=key,
                     )
                 except Exception as e:
